.. image:: https://travis-ci.com/zopefoundation/Products.CMFDefault.svg?branch=master
        :target: https://travis-ci.com/zopefoundation/Products.CMFDefault

.. image:: https://img.shields.io/pypi/v/Products.CMFDefault.svg
        :target: https://pypi.org/project/Products.CMFDefault/
        :alt: Current version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/Products.CMFDefault.svg
        :target: https://pypi.org/project/Products.CMFDefault/
        :alt: Supported Python versions


Products.CMFDefault
===================

This product declares basic content objects and provides
default implementation of some of the framework services for
the Zope Content Management Framework (CMF).
